import { Address, KeyPairSigner, OptionOrNullable } from '@solana/web3.js';
import { Client } from '@tensor-foundation/test-helpers';
import { Collection, CollectionDetails, Creator, MetadataArgs, PrintSupplyArgs, TokenStandard, Uses } from '../generated';
export interface NftData {
    name: string;
    symbol: string;
    uri: string;
    sellerFeeBasisPoints: number;
    creators: Creator[];
    primarySaleHappened?: boolean;
    isMutable?: boolean;
    tokenStandard?: TokenStandard;
    collection?: Collection;
    uses?: Uses;
    collectionDetails?: CollectionDetails;
    ruleSet?: Address;
    decimals?: number;
    printSupply?: OptionOrNullable<PrintSupplyArgs>;
}
export type Nft = {
    mint: Address;
    metadata: Address;
    masterEdition: Address;
    token: Address;
    tokenRecord?: Address;
};
export type CreateNftArgs = {
    client: Client;
    payer: KeyPairSigner | null;
    authority: KeyPairSigner;
    owner: Address;
    collectionMint?: Address;
    creators?: Creator[] | null;
    data?: NftData;
    standard?: TokenStandard;
    tokenProgram?: Address;
    ruleSet?: Address;
};
export type InitializeCollectionReturn = {
    collectionMint: Address;
    collectionMetadataAccount: Address;
    collectionMasterEditionAccount: Address;
    metadata: MetadataArgs;
};
export declare const createDefaultNft: (args: CreateNftArgs) => Promise<Nft>;
export declare const createDefaultNftInCollection: (args: CreateNftArgs) => Promise<{
    collection: Nft;
    item: Nft;
}>;
export interface MintNftAccounts {
    authority: KeyPairSigner;
    owner: Address;
    payer: KeyPairSigner | null;
    mint?: KeyPairSigner;
    tokenProgram?: Address;
}
export declare const mintNft: (client: Client, accounts: MintNftAccounts, data: NftData) => Promise<Nft>;
export declare const initializeCollection: ({ client, payer, mintAuthority, owner, creators, }: {
    client: Client;
    payer: KeyPairSigner;
    mintAuthority: KeyPairSigner;
    owner: Address;
    creators: Creator[];
}) => Promise<InitializeCollectionReturn>;
//# sourceMappingURL=mint.d.ts.map